==> haskell-parameterized-utils-2.1.1-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-parameterized-utils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 parameterized-utils
version:              2.1.1
visibility:           public
id:                   parameterized-utils-2.1.1-D652ADm12fb8Oahvk4aV29
key:                  parameterized-utils-2.1.1-D652ADm12fb8Oahvk4aV29
license:              BSD-3-Clause
copyright:            ©2016-2020 Galois, Inc.
maintainer:           jhendrix@galois.com, kquick@galois.com
author:               Galois Inc.
stability:            stable
homepage:             https://github.com/GaloisInc/parameterized-utils
synopsis:
    Classes and data structures for working with data-kind indexed types

description:
    This package contains collection classes and type representations
    used for working with values that have a single parameter.  It'\''s
    intended for things like expression libraries where one wishes
    to leverage the Haskell type-checker to improve type-safety by encoding
    the object language type system into data kinds.

category:             Data Structures, Dependent Types
abi:                  df3a9cc4d22424c830bf858d2900ba7b
exposed:              True
exposed-modules:
    Data.Parameterized Data.Parameterized.All
    Data.Parameterized.BoolRepr Data.Parameterized.Classes
    Data.Parameterized.ClassesC Data.Parameterized.Compose
    Data.Parameterized.Context Data.Parameterized.Context.Safe
    Data.Parameterized.Context.Unsafe Data.Parameterized.Ctx
    Data.Parameterized.Ctx.Proofs Data.Parameterized.DataKind
    Data.Parameterized.DecidableEq Data.Parameterized.HashTable
    Data.Parameterized.List Data.Parameterized.Map
    Data.Parameterized.NatRepr Data.Parameterized.Nonce
    Data.Parameterized.Nonce.Transformers
    Data.Parameterized.Nonce.Unsafe Data.Parameterized.Pair
    Data.Parameterized.Peano Data.Parameterized.Some
    Data.Parameterized.SymbolRepr Data.Parameterized.TH.GADT
    Data.Parameterized.TraversableF Data.Parameterized.TraversableFC
    Data.Parameterized.Utils.BinTree Data.Parameterized.Utils.Endian
    Data.Parameterized.Vector Data.Parameterized.WithRepr

hidden-modules:       Data.Parameterized.NatRepr.Internal
import-dirs:          /usr/lib/ghc-8.10.2/site-local/parameterized-utils-2.1.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/parameterized-utils-2.1.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/parameterized-utils-2.1.1

hs-libraries:         HSparameterized-utils-2.1.1-D652ADm12fb8Oahvk4aV29
depends:
    base-4.14.1.0 base-orphans-0.8.3-BGmHbketmBaEj7xM8Bozgl
    constraints-0.12-EuWfVDEhonrFAcqo3Iv7Ww containers-0.6.2.1
    deepseq-1.4.4.0 ghc-prim-0.6.1
    hashable-1.3.0.0-9tpTdzPdswvKC0QIZR69Y8
    hashtables-1.2.4.1-Hd7iV2jOuw5Wy1OSVHkVb
    lens-4.19.2-Dy8RcD96KjPDUNXKTZerr7 mtl-2.2.2
    template-haskell-2.16.0.0 text-1.2.3.2
    th-abstraction-0.4.0.0-EowzxylgIS6DLmPFoxbMpZ
    vector-0.12.1.2-3tvt8fo7Juj3zpRn38O867

haddock-interfaces:
    /usr/share/doc/haskell-parameterized-utils/html/parameterized-utils.haddock

haddock-html:         /usr/share/doc/haskell-parameterized-utils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parameterized-utils-2.1.1-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-parameterized-utils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 parameterized-utils
version:              2.1.1
visibility:           public
id:                   parameterized-utils-2.1.1-5kWS9nriivL7gnPlGkPDip
key:                  parameterized-utils-2.1.1-5kWS9nriivL7gnPlGkPDip
license:              BSD-3-Clause
copyright:            ©2016-2020 Galois, Inc.
maintainer:           jhendrix@galois.com, kquick@galois.com
author:               Galois Inc.
stability:            stable
homepage:             https://github.com/GaloisInc/parameterized-utils
synopsis:
    Classes and data structures for working with data-kind indexed types

description:
    This package contains collection classes and type representations
    used for working with values that have a single parameter.  It'\''s
    intended for things like expression libraries where one wishes
    to leverage the Haskell type-checker to improve type-safety by encoding
    the object language type system into data kinds.

category:             Data Structures, Dependent Types
abi:                  c488cbfeaa155fe1551c1d9c4b603b23
exposed:              True
exposed-modules:
    Data.Parameterized Data.Parameterized.All
    Data.Parameterized.BoolRepr Data.Parameterized.Classes
    Data.Parameterized.ClassesC Data.Parameterized.Compose
    Data.Parameterized.Context Data.Parameterized.Context.Safe
    Data.Parameterized.Context.Unsafe Data.Parameterized.Ctx
    Data.Parameterized.Ctx.Proofs Data.Parameterized.DataKind
    Data.Parameterized.DecidableEq Data.Parameterized.HashTable
    Data.Parameterized.List Data.Parameterized.Map
    Data.Parameterized.NatRepr Data.Parameterized.Nonce
    Data.Parameterized.Nonce.Transformers
    Data.Parameterized.Nonce.Unsafe Data.Parameterized.Pair
    Data.Parameterized.Peano Data.Parameterized.Some
    Data.Parameterized.SymbolRepr Data.Parameterized.TH.GADT
    Data.Parameterized.TraversableF Data.Parameterized.TraversableFC
    Data.Parameterized.Utils.BinTree Data.Parameterized.Utils.Endian
    Data.Parameterized.Vector Data.Parameterized.WithRepr

hidden-modules:       Data.Parameterized.NatRepr.Internal
import-dirs:          /usr/lib/ghc-8.10.2/site-local/parameterized-utils-2.1.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/parameterized-utils-2.1.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/parameterized-utils-2.1.1

hs-libraries:         HSparameterized-utils-2.1.1-5kWS9nriivL7gnPlGkPDip
depends:
    base-4.14.1.0 base-orphans-0.8.3-932vJJ8cPb2JsL8TDJOkHX
    constraints-0.12-9NmFnP8Ow7u7vHssUtxbcB containers-0.6.2.1
    deepseq-1.4.4.0 ghc-prim-0.6.1
    hashable-1.3.0.0-B2he7mV2CaG3Rgw4mjNDxl
    hashtables-1.2.4.1-9vE4szHxKmZD8dSnwS2lpx
    lens-4.19.2-CM7xks4zopx8m7aqAk8opQ mtl-2.2.2
    template-haskell-2.16.0.0 text-1.2.3.2
    th-abstraction-0.4.0.0-EowzxylgIS6DLmPFoxbMpZ
    vector-0.12.1.2-2m8MnQowu1eAEJcsrPdtQL

haddock-interfaces:
    /usr/share/doc/haskell-parameterized-utils/html/parameterized-utils.haddock

haddock-html:         /usr/share/doc/haskell-parameterized-utils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
